@@ -1,13 +1,13 @@
 """flyswot command line"""
 import typer
 
-from flyswot import inference
+from flyswot import cli_inference
 from flyswot import models
 
 app = typer.Typer()
 
 app.add_typer(
-    inference.app, name="predict", help="flyswot commands for making predictions"
+    cli_inference.app, name="predict", help="flyswot commands for making predictions"
 )
 app.add_typer(
     models.app, name="model", help="flyswot commands for interacting with models"
